@@ -23,10 +23,12 @@ class FormWithSpecification(forms.ModelForm):
         return instance
 
     def specification_field_values(self):
-        if not (self.instance and self.instance.pk and self.instance.specification):
+        if not (self.instance
+                and self.instance.pk
+                and self.instance.specification):
             return {}
 
         values = {}
         for field in self.instance.fields.all():
-            values[field.key] = field.get_value(self)
+            values[field.fullname] = field.get_value(self)
         return values
